#ifndef DALI_DOC_H
#define DALI_DOC_H

/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

/**
 * @defgroup dali_core DALi Core
 *
 * @brief DALi Core provides core functionalities such as scene graph-based rendering, animation, and event handling.
 *
 * It is a base module and forms the biggest part of DALi.
 *
 * @section dali_core_overview Overview
 *
 * DALi Core consists of the following groups of API:
 *
 * <table>
 * <tr>
 *    <th>API Group</th>
 *    <th>Description</th>
 * </tr>
 * <tr>
 *    <td>@ref dali_core_actors</td>
 *    <td>Actor is the primary object for interaction in DALi applications.</td>
 * </tr>
 * <tr>
 *    <td>@ref dali_core_animation</td>
 *    <td>Classes for animation which allows your objects to move around / change their properties for a specified duration.</td>
 * </tr>
 * <tr>
 *    <td>@ref dali_core_common</td>
 *    <td>Common classes for using DALi.</td>
 * </tr>
 * <tr>
 *    <td>@ref dali_core_events</td>
 *    <td>Classes for input events and gestures supported by DALi.</td>
 * </tr>
 * <tr>
 *    <td>@ref dali_core_images</td>
 *    <td>Classes for handling images.</td>
 * </tr>
 * <tr>
 *    <td>@ref dali_core_math</td>
 *    <td>Classes for basic math.</td>
 * </tr>
 * <tr>
 *    <td>@ref dali_core_object</td>
 *    <td>Classes for the handle/body pattern and property system.</td>
 * </tr>
 * <tr>
 *    <td>@ref dali_core_rendering_effects</td>
 *    <td>Classes for render task and shader effect.</td>
 * </tr>
 * <tr>
 *    <td>@ref dali_core_signals</td>
 *    <td>Classes for the signal and slot structure.</td>
 * </tr>
 * </table>
 *
 * \ifnot show_tizen_feature
 *
 * @section dali_toolkit_feature Related Features
 * This API is related with the following features:\n
 *    - http://tizen.org/feature/opengles.version.2_0\n
 *
 * It is recommended to design feature related codes in your application for reliability.\n
 *
 * You can check if a device supports the related features for this API by using @ref CAPI_SYSTEM_SYSTEM_INFO_MODULE, thereby controlling the procedure of your application.\n
 *
 * To ensure your application is only running on the device with specific features, please define the features in your manifest file using the manifest editor in the SDK.\n
 *
 * More details on featuring your application can be found from <a href="https://developer.tizen.org/development/tizen-studio/native-tools/configuring-your-app/manifest-text-editor#feature"><b>Feature Element</b>.</a>
 *
 * \endif
 *
 * @ingroup dali
 * @{
 *   @defgroup dali_core_actors Actors
 *   @brief Actor is the primary object for interaction in DALi applications.

 *   @defgroup dali_core_animation Animation
 *   @brief Classes for animation which allows your objects to move around / change their properties for a specified duration.

 *   @defgroup dali_core_common Common
 *   @brief Common classes for using DALi.

 *   @defgroup dali_core_events Events
 *   @brief Classes for input events and gestures supported by DALi.

 *   @defgroup dali_core_images Images
 *   @brief Classes for handling resource images.

 *   @defgroup dali_core_math Math
 *   @brief Classes for basic math.

 *   @defgroup dali_core_object Object
 *   @brief Classes for the handle/body pattern and property system.

 *   @defgroup dali_core_rendering_effects Rendering & Effect
 *   @brief Classes for render task and shader effect.

 *   @defgroup dali_core_signals Signal
 *   @brief Classes for the signal and slot structure.
 * @}
 */

#endif  /* DALI_DOC_H */
